@@ -795,7 +795,7 @@ class ExpectationConfiguration(SerializableDictDot):
         self.meta = meta
         self.success_on_last_run = success_on_last_run
 
-    def build_evaluation_parameters(
+    def process_evaluation_parameters(
         self, evaluation_parameters, interactive_evaluation=True, data_context=None
     ):
         if self._raw_kwargs is not None:
@@ -804,7 +804,10 @@ class ExpectationConfiguration(SerializableDictDot):
             )
 
         (evaluation_args, substituted_parameters,) = build_evaluation_parameters(
-            self._kwargs, evaluation_parameters, interactive_evaluation, data_context,
+            self._kwargs,
+            evaluation_parameters,
+            interactive_evaluation,
+            data_context,
         )
 
         self._raw_kwargs = self._kwargs
@@ -812,6 +815,15 @@ class ExpectationConfiguration(SerializableDictDot):
         if len(substituted_parameters) > 0:
             self.meta["substituted_parameters"] = substituted_parameters
 
+    def get_raw_configuration(self):
+        # return configuration without substituted evaluation parameters
+        raw_config = deepcopy(self)
+        if raw_config._raw_kwargs is not None:
+            raw_config._kwargs = raw_config._raw_kwargs
+            raw_config._raw_kwargs = None
+
+        return raw_config
+
     def patch(self, op: str, path: str, value: Any) -> "ExpectationConfiguration":
         """
 
@@ -1089,7 +1101,8 @@ class ExpectationConfiguration(SerializableDictDot):
 
             if not urn.get("metric_kwargs"):
                 nested_update(
-                    dependencies, {urn["expectation_suite_name"]: [urn["metric_name"]]},
+                    dependencies,
+                    {urn["expectation_suite_name"]: [urn["metric_name"]]},
                 )
             else:
                 nested_update(
@@ -1112,15 +1125,21 @@ class ExpectationConfiguration(SerializableDictDot):
         return get_expectation_impl(self.expectation_type)
 
     def validate(
-        self, validator, runtime_configuration=None,
+        self,
+        validator,
+        runtime_configuration=None,
     ):
         expectation_impl = self._get_expectation_impl()
         return expectation_impl(self).validate(
-            validator=validator, runtime_configuration=runtime_configuration,
+            validator=validator,
+            runtime_configuration=runtime_configuration,
         )
 
     def metrics_validate(
-        self, metrics: Dict, runtime_configuration: dict = None, execution_engine=None,
+        self,
+        metrics: Dict,
+        runtime_configuration: dict = None,
+        execution_engine=None,
     ):
         expectation_impl = self._get_expectation_impl()
         return expectation_impl(self).metrics_validate(
