@@ -21,10 +21,22 @@ except ImportError:
 
 
 SCHEMAS = {
-    "api_np": {"NegativeInfinity": -np.inf, "PositiveInfinity": np.inf,},
-    "api_cast": {"NegativeInfinity": -float("inf"), "PositiveInfinity": float("inf"),},
-    "mysql": {"NegativeInfinity": -1.79e308, "PositiveInfinity": 1.79e308,},
-    "mssql": {"NegativeInfinity": -1.79e308, "PositiveInfinity": 1.79e308,},
+    "api_np": {
+        "NegativeInfinity": -np.inf,
+        "PositiveInfinity": np.inf,
+    },
+    "api_cast": {
+        "NegativeInfinity": -float("inf"),
+        "PositiveInfinity": float("inf"),
+    },
+    "mysql": {
+        "NegativeInfinity": -1.79e308,
+        "PositiveInfinity": 1.79e308,
+    },
+    "mssql": {
+        "NegativeInfinity": -1.79e308,
+        "PositiveInfinity": 1.79e308,
+    },
 }
 
 
@@ -615,7 +627,8 @@ def get_approximate_percentile_disc_sql(selects: List, sql_engine_dialect: Any)
 
 
 def check_sql_engine_dialect(
-    actual_sql_engine_dialect: Any, candidate_sql_engine_dialect: Any,
+    actual_sql_engine_dialect: Any,
+    candidate_sql_engine_dialect: Any,
 ) -> bool:
     try:
         # noinspection PyTypeChecker
