@@ -12,25 +12,8 @@ except ImportError:
 
 
 class InferredAssetSqlDataConnector(ConfiguredAssetSqlDataConnector):
-    """A DataConnector that infers data_asset names by introspecting a SQL database
-
-    Args:
-        name (str): The name of this DataConnector
-        datasource_name (str): The name of the Datasource that contains it
-        execution_engine (ExecutionEngine): An ExecutionEngine
-        data_asset_name_prefix (str): An optional prefix to prepend to inferred data_asset_names
-        data_asset_name_suffix (str): An optional suffix to append to inferred data_asset_names
-        include_schema_name (bool): Should the data_asset_name include the schema as a prefix?
-        splitter_method (str): A method to split the target table into multiple Batches
-        splitter_kwargs (dict): Keyword arguments to pass to splitter_method
-        sampling_method (str): A method to downsample within a target Batch
-        sampling_kwargs (dict): Keyword arguments to pass to sampling_method
-        excluded_tables (List): A list of tables to ignore when inferring data asset_names
-        included_tables (List): If not None, only include tables in this list when inferring data asset_names
-        skip_inapplicable_tables (bool):
-            If True, tables that can't be successfully queried using sampling and splitter methods are excluded from inferred data_asset_names.
-            If False, the class will throw an error during initialization if any such tables are encountered.
-        introspection_directives (Dict): Arguments passed to the introspection method to guide introspection
+    """
+    A DataConnector that infers data_asset names by introspecting a SQL database
     """
 
     def __init__(
@@ -50,6 +33,27 @@ class InferredAssetSqlDataConnector(ConfiguredAssetSqlDataConnector):
         skip_inapplicable_tables: bool = True,
         introspection_directives: Dict = None,
     ):
+        """
+        InferredAssetDataConnector for connecting to data on a SQL database
+
+        Args:
+            name (str): The name of this DataConnector
+            datasource_name (str): The name of the Datasource that contains it
+            execution_engine (ExecutionEngine): An ExecutionEngine
+            data_asset_name_prefix (str): An optional prefix to prepend to inferred data_asset_names
+            data_asset_name_suffix (str): An optional suffix to append to inferred data_asset_names
+            include_schema_name (bool): Should the data_asset_name include the schema as a prefix?
+            splitter_method (str): A method to split the target table into multiple Batches
+            splitter_kwargs (dict): Keyword arguments to pass to splitter_method
+            sampling_method (str): A method to downsample within a target Batch
+            sampling_kwargs (dict): Keyword arguments to pass to sampling_method
+            excluded_tables (List): A list of tables to ignore when inferring data asset_names
+            included_tables (List): If not None, only include tables in this list when inferring data asset_names
+            skip_inapplicable_tables (bool):
+                If True, tables that can't be successfully queried using sampling and splitter methods are excluded from inferred data_asset_names.
+                If False, the class will throw an error during initialization if any such tables are encountered.
+            introspection_directives (Dict): Arguments passed to the introspection method to guide introspection
+        """
         self._data_asset_name_prefix = data_asset_name_prefix
         self._data_asset_name_suffix = data_asset_name_suffix
         self._include_schema_name = include_schema_name
@@ -166,7 +170,8 @@ class InferredAssetSqlDataConnector(ConfiguredAssetSqlDataConnector):
             # Attempt to fetch a list of partition_definitions from the table
             try:
                 self._get_partition_definition_list_from_data_asset_config(
-                    data_asset_name, data_asset_config,
+                    data_asset_name,
+                    data_asset_config,
                 )
             except OperationalError as e:
                 # If it doesn't work, then...
@@ -201,6 +206,7 @@ class InferredAssetSqlDataConnector(ConfiguredAssetSqlDataConnector):
         inspector = sa.inspect(engine)
 
         selected_schema_name = schema_name
+
         tables = []
         for schema_name in inspector.get_schema_names():
             if (
@@ -227,21 +233,23 @@ class InferredAssetSqlDataConnector(ConfiguredAssetSqlDataConnector):
                     }
                 )
 
+            # Note Abe 20201112: This logic is currently untested.
             if include_views:
-                try:
-                    for view_name in inspector.get_view_names(schema=schema_name):
-                        if (ignore_information_schemas_and_system_tables) and (
-                            view_name in system_tables
-                        ):
-                            continue
-                        tables.append(
-                            {
-                                "schema_name": schema_name,
-                                "table_name": view_name,
-                                "type": "view",
-                            }
-                        )
-                except NotImplementedError:
-                    # Not implemented by bigquery dialect
-                    pass
+                # Note: this is not implemented for bigquery
+
+                for view_name in inspector.get_view_names(schema=schema_name):
+
+                    if (ignore_information_schemas_and_system_tables) and (
+                        table_name in system_tables
+                    ):
+                        continue
+
+                    tables.append(
+                        {
+                            "schema_name": schema_name,
+                            "table_name": view_name,
+                            "type": "view",
+                        }
+                    )
+
         return tables
