@@ -1,13 +1,13 @@
 import copy
 import logging
-from typing import Any, Callable, Dict, List, Optional, Union
+from typing import Any, Dict, List, Optional, Union
 
+import great_expectations.exceptions as ge_exceptions
 from great_expectations.core.batch import (
     Batch,
     BatchDefinition,
     BatchMarkers,
     BatchRequest,
-    PartitionRequest,
 )
 from great_expectations.data_context.util import instantiate_class_from_config
 from great_expectations.datasource.data_connector import DataConnector
@@ -42,20 +42,24 @@ class BaseDatasource:
 
         self._data_context_root_directory = data_context_root_directory
 
-        self._execution_engine = instantiate_class_from_config(
-            config=execution_engine,
-            runtime_environment={},
-            config_defaults={"module_name": "great_expectations.execution_engine"},
-        )
-
-        self._datasource_config = {
-            "execution_engine": execution_engine,
-        }
+        try:
+            self._execution_engine = instantiate_class_from_config(
+                config=execution_engine,
+                runtime_environment={},
+                config_defaults={"module_name": "great_expectations.execution_engine"},
+            )
+            self._datasource_config = {
+                "execution_engine": execution_engine,
+            }
+        except Exception as e:
+            raise ge_exceptions.ExecutionEngineError(message=str(e))
 
         self._data_connectors = {}
 
     def get_batch_from_batch_definition(
-        self, batch_definition: BatchDefinition, batch_data: Any = None,
+        self,
+        batch_definition: BatchDefinition,
+        batch_data: Any = None,
     ) -> Batch:
         """
         Note: this method should *not* be used when getting a Batch from a BatchRequest, since it does not capture BatchRequest metadata.
@@ -157,7 +161,8 @@ class BaseDatasource:
                 batch_spec,
                 batch_markers,
             ) = data_connector.get_batch_data_and_metadata(
-                batch_definition=batch_definition, batch_data=batch_data,
+                batch_definition=batch_definition,
+                batch_data=batch_data,
             )
 
             new_batch: Batch = Batch(
@@ -171,7 +176,9 @@ class BaseDatasource:
             return [new_batch]
 
     def _build_data_connector_from_config(
-        self, name: str, config: Dict[str, Any],
+        self,
+        name: str,
+        config: Dict[str, Any],
     ) -> DataConnector:
         """Build a DataConnector using the provided configuration and return the newly-built DataConnector."""
         new_data_connector: DataConnector = instantiate_class_from_config(
@@ -238,8 +245,10 @@ class BaseDatasource:
         data_connector: DataConnector = self.data_connectors[
             batch_request.data_connector_name
         ]
-        batch_definition_list = data_connector.get_batch_definition_list_from_batch_request(
-            batch_request=batch_request
+        batch_definition_list = (
+            data_connector.get_batch_definition_list_from_batch_request(
+                batch_request=batch_request
+            )
         )
 
         return batch_definition_list
@@ -294,11 +303,11 @@ class BaseDatasource:
         return self._execution_engine
 
     @property
-    def data_connectors(self):
+    def data_connectors(self) -> dict:
         return self._data_connectors
 
     @property
-    def config(self):
+    def config(self) -> dict:
         return copy.deepcopy(self._datasource_config)
 
 
@@ -336,14 +345,17 @@ class Datasource(BaseDatasource):
         if data_connectors is None:
             data_connectors = {}
         self._data_connectors = data_connectors
+        self._datasource_config.update(
+            {"data_connectors": copy.deepcopy(data_connectors)}
+        )
         self._init_data_connectors(data_connector_configs=data_connectors)
 
-        self._datasource_config.update({"data_connectors": data_connectors})
-
     def _init_data_connectors(
-        self, data_connector_configs: Dict[str, Dict[str, Any]],
+        self,
+        data_connector_configs: Dict[str, Dict[str, Any]],
     ):
         for name, config in data_connector_configs.items():
             self._build_data_connector_from_config(
-                name=name, config=config,
+                name=name,
+                config=config,
             )
