@@ -118,10 +118,6 @@ class StoreConfigurationError(DataContextError):
     pass
 
 
-class DatasourceConfigurationError(DataContextError):
-    pass
-
-
 class InvalidExpectationKwargsError(GreatExpectationsError):
     pass
 
@@ -231,7 +227,9 @@ class PluginClassNotFoundError(DataContextError, AttributeError):
             )
         else:
             self.cli_colored_message = colored_template.format(
-                module_snippet, class_snippet, class_snippet,
+                module_snippet,
+                class_snippet,
+                class_snippet,
             )
         super().__init__(self.message)
 
@@ -282,14 +280,23 @@ class BatchSpecError(DataContextError):
         super().__init__(self.message)
 
 
-class DatasourceInitializationError(GreatExpectationsError):
+class DatasourceError(DataContextError):
     def __init__(self, datasource_name, message):
         self.message = "Cannot initialize datasource {}, error: {}".format(
-            datasource_name, message,
+            datasource_name,
+            message,
         )
         super().__init__(self.message)
 
 
+class DatasourceConfigurationError(DatasourceError):
+    pass
+
+
+class DatasourceInitializationError(DatasourceError):
+    pass
+
+
 class DatasourceKeyPairAuthBadPassphraseError(DatasourceInitializationError):
     pass
 
@@ -298,12 +305,6 @@ class InvalidConfigValueTypeError(DataContextError):
     pass
 
 
-class DatasourceError(DataContextError):
-    def __init__(self, message):
-        self.message = message
-        super().__init__(self.message)
-
-
 class DataConnectorError(DataContextError):
     def __init__(self, message):
         self.message = message
