@@ -82,17 +82,23 @@ Notes:
         self.discard_subset_failing_expectations = kwargs.get(
             "discard_subset_failing_expectations", False
         )
-        boto3_options: dict = None
-        if boto3_options is None:
-            boto3_options = {}
+        boto3_options: dict = kwargs.get("boto3_options", {})
 
         # Try initializing boto3 client. If unsuccessful, we'll catch it when/if a S3BatchSpec is passed in.
         try:
             self._s3 = boto3.client("s3", **boto3_options)
         except (TypeError, AttributeError):
             self._s3 = None
+
         super().__init__(*args, **kwargs)
 
+        self._config.update(
+            {
+                "discard_subset_failing_expectations": self.discard_subset_failing_expectations,
+                "boto3_options": boto3_options,
+            }
+        )
+
     def configure_validator(self, validator):
         super().configure_validator(validator)
         validator.expose_dataframe_methods = True
@@ -231,13 +237,13 @@ Notes:
     def guess_reader_method_from_path(path):
         """Helper method for deciding which reader to use to read in a certain path.
 
-               Args:
-                   path (str): the to use to guess
+        Args:
+            path (str): the to use to guess
 
-               Returns:
-                   ReaderMethod to use for the filepath
+        Returns:
+            ReaderMethod to use for the filepath
 
-               """
+        """
         if path.endswith(".csv") or path.endswith(".tsv"):
             return {"reader_method": "read_csv"}
         elif path.endswith(".parquet"):
@@ -420,12 +426,16 @@ Notes:
 
     ### Splitter methods for partitioning dataframes ###
     @staticmethod
-    def _split_on_whole_table(df,) -> pd.DataFrame:
+    def _split_on_whole_table(
+        df,
+    ) -> pd.DataFrame:
         return df
 
     @staticmethod
     def _split_on_column_value(
-        df, column_name: str, partition_definition: dict,
+        df,
+        column_name: str,
+        partition_definition: dict,
     ) -> pd.DataFrame:
 
         return df[df[column_name] == partition_definition[column_name]]
@@ -446,7 +456,10 @@ Notes:
 
     @staticmethod
     def _split_on_divided_integer(
-        df, column_name: str, divisor: int, partition_definition: dict,
+        df,
+        column_name: str,
+        divisor: int,
+        partition_definition: dict,
     ):
         """Divide the values in the named column by `divisor`, and split on that"""
 
@@ -459,7 +472,10 @@ Notes:
 
     @staticmethod
     def _split_on_mod_integer(
-        df, column_name: str, mod: int, partition_definition: dict,
+        df,
+        column_name: str,
+        mod: int,
+        partition_definition: dict,
     ):
         """Divide the values in the named column by `divisor`, and split on that"""
 
@@ -470,7 +486,9 @@ Notes:
 
     @staticmethod
     def _split_on_multi_column_values(
-        df, column_names: List[str], partition_definition: dict,
+        df,
+        column_names: List[str],
+        partition_definition: dict,
     ):
         """Split on the joint values in the named columns"""
 
@@ -514,7 +532,8 @@ Notes:
 
     @staticmethod
     def _sample_using_random(
-        df, p: float = 0.1,
+        df,
+        p: float = 0.1,
     ):
         """Take a random sample of rows, retaining proportion p
 
@@ -524,14 +543,19 @@ Notes:
 
     @staticmethod
     def _sample_using_mod(
-        df, column_name: str, mod: int, value: int,
+        df,
+        column_name: str,
+        mod: int,
+        value: int,
     ):
         """Take the mod of named column, and only keep rows that match the given value"""
         return df[df[column_name].map(lambda x: x % mod == value)]
 
     @staticmethod
     def _sample_using_a_list(
-        df, column_name: str, value_list: list,
+        df,
+        column_name: str,
+        value_list: list,
     ):
         """Match the values in the named column against value_list, and only keep the matches"""
         return df[df[column_name].isin(value_list)]
