@@ -5,6 +5,7 @@ import pandas as pd
 
 from great_expectations.core.expectation_configuration import ExpectationConfiguration
 from great_expectations.execution_engine import ExecutionEngine, PandasExecutionEngine
+from great_expectations.expectations.util import render_evaluation_parameter_string
 
 from ...render.renderer.renderer import renderer
 from ...render.types import RenderedGraphContent, RenderedStringTemplateContent
@@ -111,6 +112,7 @@ class ExpectColumnDistinctValuesToBeInSet(ColumnExpectation):
 
     @classmethod
     @renderer(renderer_type="renderer.prescriptive")
+    @render_evaluation_parameter_string
     def _prescriptive_renderer(
         cls,
         configuration=None,
@@ -201,7 +203,12 @@ class ExpectColumnDistinctValuesToBeInSet(ColumnExpectation):
                 value_count_dict["count"] for value_count_dict in value_count_dicts
             ]
 
-        df = pd.DataFrame({"value": values, "count": counts,})
+        df = pd.DataFrame(
+            {
+                "value": values,
+                "count": counts,
+            }
+        )
 
         if len(values) > 60:
             return None
