@@ -12,6 +12,7 @@ from great_expectations.execution_engine import (
     PandasExecutionEngine,
     SparkDFExecutionEngine,
 )
+from great_expectations.expectations.util import render_evaluation_parameter_string
 
 from ...core.batch import Batch
 from ...data_asset.util import parse_result_format
@@ -93,6 +94,7 @@ class ExpectColumnValuesToBeDateutilParseable(ColumnMapExpectation):
 
     @classmethod
     @renderer(renderer_type="renderer.prescriptive")
+    @render_evaluation_parameter_string
     def _prescriptive_renderer(
         cls,
         configuration=None,
