@@ -18,6 +18,7 @@ from great_expectations.expectations.core.expect_column_values_to_be_of_type imp
 )
 from great_expectations.expectations.expectation import ColumnMapExpectation
 from great_expectations.expectations.registry import get_metric_kwargs
+from great_expectations.expectations.util import render_evaluation_parameter_string
 from great_expectations.render.renderer.renderer import renderer
 from great_expectations.render.types import RenderedStringTemplateContent
 from great_expectations.render.util import (
@@ -122,6 +123,7 @@ class ExpectColumnValuesToBeInTypeList(ColumnMapExpectation):
 
     @classmethod
     @renderer(renderer_type="renderer.prescriptive")
+    @render_evaluation_parameter_string
     def _prescriptive_renderer(
         cls,
         configuration=None,
@@ -206,7 +208,9 @@ class ExpectColumnValuesToBeInTypeList(ColumnMapExpectation):
         ]
 
     def _validate_pandas(
-        self, actual_column_type, expected_types_list,
+        self,
+        actual_column_type,
+        expected_types_list,
     ):
         if expected_types_list is None:
             success = True
@@ -277,7 +281,9 @@ class ExpectColumnValuesToBeInTypeList(ColumnMapExpectation):
         }
 
     def _validate_spark(
-        self, actual_column_type, expected_types_list,
+        self,
+        actual_column_type,
+        expected_types_list,
     ):
         if expected_types_list is None:
             success = True
