@@ -638,11 +638,12 @@ class Expectation(ABC, metaclass=MetaExpectation):
         if configuration is None:
             configuration = self.configuration
 
-        configuration.build_evaluation_parameters(
+        configuration.process_evaluation_parameters(
             evaluation_parameters, interactive_evaluation, data_context
         )
         evr = validator.graph_validate(
-            configurations=[configuration], runtime_configuration=runtime_configuration,
+            configurations=[configuration],
+            runtime_configuration=runtime_configuration,
         )[0]
 
         return evr
@@ -742,11 +743,22 @@ class TableExpectation(Expectation, ABC):
         try:
             # Ensuring Proper interval has been provided
             assert min_val is None or isinstance(
-                min_val, (float, int)
+                min_val, (float, int, dict)
             ), "Provided min threshold must be a number"
+            if isinstance(min_val, dict):
+                assert (
+                    "$PARAMETER" in min_val
+                ), 'Evaluation Parameter dict for min_value kwarg must have "$PARAMETER" key'
+
             assert max_val is None or isinstance(
-                max_val, (float, int)
+                max_val, (float, int, dict)
             ), "Provided max threshold must be a number"
+            if isinstance(max_val, dict):
+                assert "$PARAMETER" in max_val, (
+                    "Evaluation Parameter dict for max_value "
+                    "kwarg "
+                    'must have "$PARAMETER" key'
+                )
 
         except AssertionError as e:
             raise InvalidExpectationConfigurationError(str(e))
