@@ -76,7 +76,11 @@ class ValidationResultsPageRenderer(Renderer):
         ]
 
     # TODO: deprecate dual batch api support in 0.14
-    def render(self, validation_results: ExpectationSuiteValidationResult):
+    def render(
+        self,
+        validation_results: ExpectationSuiteValidationResult,
+        evaluation_parameters=None,
+    ):
         run_id = validation_results.meta["run_id"]
         if isinstance(run_id, str):
             try:
@@ -92,9 +96,11 @@ class ValidationResultsPageRenderer(Renderer):
             run_time = run_id.run_time.strftime("%Y-%m-%dT%H:%M:%S.%fZ")
 
         expectation_suite_name = validation_results.meta["expectation_suite_name"]
-        batch_kwargs = validation_results.meta.get(
-            "batch_kwargs", {}
-        ) or validation_results.meta.get("batch_spec", {})
+        batch_kwargs = (
+            validation_results.meta.get("batch_kwargs", {})
+            or validation_results.meta.get("batch_spec", {})
+            or {}
+        )
 
         # add datasource key to batch_kwargs if missing
         if "datasource" not in batch_kwargs and "datasource" not in batch_kwargs:
@@ -118,7 +124,6 @@ class ValidationResultsPageRenderer(Renderer):
             columns[column].append(evr)
 
         ordered_columns = Renderer._get_column_list_from_evrs(validation_results)
-
         overview_content_blocks = [
             self._render_validation_header(validation_results),
             self._render_validation_statistics(validation_results=validation_results),
@@ -194,15 +199,18 @@ class ValidationResultsPageRenderer(Renderer):
         if "Table-Level Expectations" in columns:
             sections += [
                 self._column_section_renderer.render(
-                    validation_results=columns["Table-Level Expectations"]
+                    validation_results=columns["Table-Level Expectations"],
+                    evaluation_parameters=validation_results.evaluation_parameters,
                 )
             ]
 
         sections += [
-            self._column_section_renderer.render(validation_results=columns[column],)
+            self._column_section_renderer.render(
+                validation_results=columns[column],
+                evaluation_parameters=validation_results.evaluation_parameters,
+            )
             for column in ordered_columns
         ]
-
         if self.run_info_at_end:
             sections += [
                 RenderedSectionContent(
@@ -279,6 +287,7 @@ class ValidationResultsPageRenderer(Renderer):
             html_success_icon = (
                 '<i class="fas fa-times text-danger" aria-hidden="true"></i>'
             )
+
         return RenderedHeaderContent(
             **{
                 "content_block_type": "header",
@@ -381,7 +390,6 @@ class ValidationResultsPageRenderer(Renderer):
     @classmethod
     def _render_nested_table_from_dict(cls, input_dict, header=None, sub_table=False):
         table_rows = []
-
         for kwarg, value in input_dict.items():
             if not isinstance(value, (dict, OrderedDict)):
                 table_row = [
@@ -395,7 +403,11 @@ class ValidationResultsPageRenderer(Renderer):
                                     "default": {"styles": {"word-break": "break-all"}},
                                 },
                             },
-                            "styling": {"parent": {"classes": ["pr-3"],}},
+                            "styling": {
+                                "parent": {
+                                    "classes": ["pr-3"],
+                                }
+                            },
                         }
                     ),
                     RenderedStringTemplateContent(
@@ -408,7 +420,11 @@ class ValidationResultsPageRenderer(Renderer):
                                     "default": {"styles": {"word-break": "break-all"}},
                                 },
                             },
-                            "styling": {"parent": {"classes": [],}},
+                            "styling": {
+                                "parent": {
+                                    "classes": [],
+                                }
+                            },
                         }
                     ),
                 ]
@@ -424,7 +440,11 @@ class ValidationResultsPageRenderer(Renderer):
                                     "default": {"styles": {"word-break": "break-all"}},
                                 },
                             },
-                            "styling": {"parent": {"classes": ["pr-3"],}},
+                            "styling": {
+                                "parent": {
+                                    "classes": ["pr-3"],
+                                }
+                            },
                         }
                     ),
                     cls._render_nested_table_from_dict(value, sub_table=True),
@@ -687,7 +707,10 @@ class ExpectationSuitePageRenderer(Renderer):
             # "This Expectation suite was first generated by {BasicDatasetProfiler} on {date}, using version {xxx} of Great Expectations.",
             # "{name}, {name}, and {name} have also contributed additions and revisions.",
             "This Expectation suite currently contains %d total Expectations across %d columns."
-            % (total_expectations, total_columns,),
+            % (
+                total_expectations,
+                total_columns,
+            ),
         ]
 
         if "notes" in expectations.meta:
