@@ -1,15 +1,27 @@
+import copy
 import importlib
 import json
 import logging
 import os
 import time
+from collections import OrderedDict
 from functools import wraps
-from inspect import getcallargs
+from gc import get_referrers
+from inspect import (
+    ArgInfo,
+    BoundArguments,
+    Parameter,
+    Signature,
+    currentframe,
+    getargvalues,
+    getclosurevars,
+    getmodule,
+    signature,
+)
 from pathlib import Path
-from types import ModuleType
-from typing import Any, Callable, Union
+from types import CodeType, FrameType, ModuleType
+from typing import Any, Callable, Optional, Union
 
-import black
 from pkg_resources import Distribution
 
 from great_expectations.core.expectation_suite import expectationSuiteSchema
@@ -29,7 +41,7 @@ except ModuleNotFoundError:
 logger = logging.getLogger(__name__)
 
 
-def measure_execution_time(func) -> Callable:
+def measure_execution_time(func: Callable = None) -> Callable:
     @wraps(func)
     def compute_delta_t(*args, **kwargs) -> Callable:
         time_begin: int = int(round(time.time() * 1000))
@@ -38,9 +50,10 @@ def measure_execution_time(func) -> Callable:
         finally:
             time_end: int = int(round(time.time() * 1000))
             delta_t: int = time_end - time_begin
-            call_args: dict = getcallargs(func, *args, **kwargs)
+            bound_args: BoundArguments = signature(func).bind(*args, **kwargs)
+            call_args: OrderedDict = bound_args.arguments
             print(
-                f"Total execution time of function {func.__name__}({call_args}): {delta_t} ms."
+                f"Total execution time of function {func.__name__}({str(dict(call_args))}): {delta_t} ms."
             )
 
     return compute_delta_t
@@ -61,6 +74,72 @@ def get_project_distribution() -> Union[Distribution, None]:
     return None
 
 
+# Returns the object reference to the currently running function (i.e., the immediate function under execution).
+def get_currently_executing_function() -> Callable:
+    cf: FrameType = currentframe()
+    fb: FrameType = cf.f_back
+    fc: CodeType = fb.f_code
+    func_obj: Callable = [
+        referer
+        for referer in get_referrers(fc)
+        if getattr(referer, "__code__", None) is fc
+        and getclosurevars(referer).nonlocals.items() <= fb.f_locals.items()
+    ][0]
+    return func_obj
+
+
+# noinspection SpellCheckingInspection
+def get_currently_executing_function_call_arguments(
+    include_module_name: bool = False, include_caller_names: bool = False, **kwargs
+) -> dict:
+    cf: FrameType = currentframe()
+    fb: FrameType = cf.f_back
+    argvs: ArgInfo = getargvalues(fb)
+    fc: CodeType = fb.f_code
+    cur_func_obj: Callable = [
+        referer
+        for referer in get_referrers(fc)
+        if getattr(referer, "__code__", None) is fc
+        and getclosurevars(referer).nonlocals.items() <= fb.f_locals.items()
+    ][0]
+    cur_mod = getmodule(cur_func_obj)
+    sig: Signature = signature(cur_func_obj)
+    params: dict = {}
+    var_positional: dict = {}
+    var_keyword: dict = {}
+    for key, param in sig.parameters.items():
+        val: Any = argvs.locals[key]
+        params[key] = val
+        if param.kind == Parameter.VAR_POSITIONAL:
+            var_positional[key] = val
+        elif param.kind == Parameter.VAR_KEYWORD:
+            var_keyword[key] = val
+    bound_args: BoundArguments = sig.bind(**params)
+    call_args: OrderedDict = bound_args.arguments
+
+    call_args_dict: dict = dict(call_args)
+
+    for key, value in var_positional.items():
+        call_args_dict[key] = value
+
+    for key, value in var_keyword.items():
+        call_args_dict.pop(key)
+        call_args_dict.update(value)
+
+    if include_module_name:
+        call_args_dict.update({"module_name": cur_mod.__name__})
+
+    if not include_caller_names:
+        if call_args.get("cls"):
+            call_args_dict.pop("cls", None)
+        if call_args.get("self"):
+            call_args_dict.pop("self", None)
+
+    call_args_dict.update(**kwargs)
+
+    return call_args_dict
+
+
 def verify_dynamic_loading_support(module_name: str, package_name: str = None) -> None:
     """
     :param module_name: a possibly-relative name of a module
@@ -678,18 +757,111 @@ def gen_directory_tree_str(startpath):
 
 
 def lint_code(code):
-    """Lint strings of code passed in."""
-    black_file_mode = black.FileMode()
-    if not isinstance(code, str):
-        raise TypeError
+    """Lint strings of code passed in. Optional dependency "black" must be installed."""
     try:
-        linted_code = black.format_file_contents(code, fast=True, mode=black_file_mode)
-        return linted_code
-    except (black.NothingChanged, RuntimeError):
+        import black
+
+        black_file_mode = black.FileMode()
+        if not isinstance(code, str):
+            raise TypeError
+        try:
+            linted_code = black.format_file_contents(
+                code, fast=True, mode=black_file_mode
+            )
+            return linted_code
+        except (black.NothingChanged, RuntimeError):
+            return code
+    except ImportError:
+        logger.warning(
+            "Please install the optional dependency 'black' to enable linting. Returning input with no changes."
+        )
         return code
 
 
-def get_context():
-    from great_expectations.data_context.data_context_v3 import DataContextV3
+def filter_properties_dict(
+    properties: dict,
+    keep_fields: Optional[list] = None,
+    delete_fields: Optional[list] = None,
+    clean_empty: Optional[bool] = True,
+    inplace: Optional[bool] = False,
+) -> Optional[dict]:
+    """Filter the entries of the source dictionary according to directives concerning the existing keys and values.
 
-    return DataContextV3()
+    Args:
+        properties: source dictionary to be filtered according to the supplied filtering directives
+        keep_fields: list of keys that must be retained, with the understanding that all other entries will be deleted
+        delete_fields: list of keys that must be deleted, with the understanding that all other entries will be retained
+        clean_empty: If True, then in addition to other filtering directives, delete entries, whose values are Falsy
+        inplace: If True, then modify the source properties dictionary; otherwise, make a copy for filtering purposes
+
+    Returns:
+        The (possibly) filtered properties dictionary (or None if no entries remain after filtering is performed)
+    """
+    if keep_fields and delete_fields:
+        raise ValueError(
+            "Only one of keep_fields and delete_fields filtering directives can be specified."
+        )
+
+    if not inplace:
+        properties = copy.deepcopy(properties)
+
+    keys_for_deletion: list = []
+
+    if keep_fields:
+        keys_for_deletion.extend(
+            [key for key, value in properties.items() if key not in keep_fields]
+        )
+
+    if delete_fields:
+        keys_for_deletion.extend(
+            [key for key, value in properties.items() if key in delete_fields]
+        )
+
+    if clean_empty:
+        keys_for_deletion.extend(
+            [
+                key
+                for key, value in properties.items()
+                if not (
+                    (keep_fields and key in keep_fields)
+                    or is_numeric(value=value)
+                    or value
+                )
+            ]
+        )
+
+    keys_for_deletion = list(set(keys_for_deletion))
+
+    for key in keys_for_deletion:
+        del properties[key]
+
+    if inplace:
+        return None
+
+    return properties
+
+
+def is_numeric(value: Any) -> bool:
+    return value is not None and (is_int(value) or is_float(value))
+
+
+def is_int(value: Any) -> bool:
+    try:
+        num: int = int(value)
+    except (TypeError, ValueError):
+        return False
+    return True
+
+
+def is_float(value: Any) -> bool:
+    try:
+        num: float = float(value)
+    except (TypeError, ValueError):
+        return False
+    return True
+
+
+def get_context():
+    from great_expectations.data_context.data_context import DataContext
+
+    return DataContext()
