@@ -303,10 +303,20 @@ class Validator:
         child_node.metric_dependencies = metric_dependencies
 
         if parent_node:
-            graph.add(MetricEdge(parent_node, child_node,))
+            graph.add(
+                MetricEdge(
+                    parent_node,
+                    child_node,
+                )
+            )
 
         if len(metric_dependencies) == 0:
-            graph.add(MetricEdge(child_node, None,))
+            graph.add(
+                MetricEdge(
+                    child_node,
+                    None,
+                )
+            )
 
         else:
             for metric_dependency in metric_dependencies.values():
@@ -1035,8 +1045,8 @@ class Validator:
             # So, we load them in reverse order
 
             if data_context is not None:
-                runtime_evaluation_parameters = data_context.evaluation_parameter_store.get_bind_params(
-                    run_id
+                runtime_evaluation_parameters = (
+                    data_context.evaluation_parameter_store.get_bind_params(run_id)
                 )
             else:
                 runtime_evaluation_parameters = {}
@@ -1065,7 +1075,10 @@ class Validator:
                     warnings.warn(
                         "WARNING: This configuration object was built using version %s of great_expectations, but "
                         "is currently being validated by version %s."
-                        % (suite_ge_version, ge_version,)
+                        % (
+                            suite_ge_version,
+                            ge_version,
+                        )
                     )
             else:
                 warnings.warn(
